@@ -893,6 +893,11 @@ func (m *Method) create(buf *file.Buffer, replace bool) error {
 
 		buf.L("// Populate the statement arguments. ")
 		for i, field := range fields {
+			if field.Config.Has("create_timestamp") || field.Config.Has("update_timestamp") {
+				buf.L("args[%d] = time.Now().UTC().Format(time.RFC3339)", i)
+				continue
+			}
+
 			if util.IsNeitherFalseNorEmpty(field.Config.Get("marshal")) {
 				marshalFunc := "marshal"
 				if strings.ToLower(field.Config.Get("marshal")) == "json" {
@@ -1077,7 +1082,20 @@ func (m *Method) rename(buf *file.Buffer) error {
 		}
 	}
 
-	buf.L("result, err := stmt.Exec(to, %s)", mapping.FieldParamsMarshal(nk))
+	updatedAt := false
+	for _, field := range mapping.Fields {
+		if field.Config.Has("update_timestamp") {
+			updatedAt = true
+			break
+		}
+	}
+
+	if updatedAt {
+		buf.L("result, err := stmt.Exec(to, %s, %s)", "time.Now().UTC().Format(time.RFC3339)", mapping.FieldParamsMarshal(nk))
+	} else {
+		buf.L("result, err := stmt.Exec(to, %s)", mapping.FieldParamsMarshal(nk))
+	}
+
 	m.ifErrNotNil(buf, true, fmt.Sprintf("fmt.Errorf(\"Rename %s failed: %%w\", err)", mapping.Name))
 	buf.L("n, err := result.RowsAffected()")
 	m.ifErrNotNil(buf, true, "fmt.Errorf(\"Fetch affected rows failed: %w\", err)")
@@ -1202,6 +1220,11 @@ func (m *Method) update(buf *file.Buffer) error {
 		fields := updateMapping.ColumnFields("ID") // This exclude the ID column, which is autogenerated.
 		params := make([]string, len(fields))
 		for i, field := range fields {
+			if field.Config.Has("update_timestamp") {
+				params[i] = "time.Now().UTC().Format(time.RFC3339)"
+				continue
+			}
+
 			if util.IsNeitherFalseNorEmpty(field.Config.Get("marshal")) {
 				marshalFunc := "marshal"
 				if strings.ToLower(field.Config.Get("marshal")) == "json" {
