@@ -18,7 +18,6 @@ import (
 
 	"github.com/flosch/pongo2/v6"
 	"github.com/google/uuid"
-	liblxc "github.com/lxc/go-lxc"
 
 	incus "github.com/lxc/incus/v6/client"
 	"github.com/lxc/incus/v6/internal/instance"
@@ -233,39 +232,6 @@ func lxcValidConfig(rawLxc string) error {
 				`"limits.kernel.[limit name]" and not ` +
 				`directly via "lxc.prlimit.[limit name]"`)
 		}
-
-		networkKeyPrefix := "lxc.net."
-		if !liblxc.RuntimeLiblxcVersionAtLeast(liblxc.Version(), 2, 1, 0) {
-			networkKeyPrefix = "lxc.network."
-		}
-
-		if strings.HasPrefix(key, networkKeyPrefix) {
-			fields := strings.Split(key, ".")
-
-			if !liblxc.RuntimeLiblxcVersionAtLeast(liblxc.Version(), 2, 1, 0) {
-				// lxc.network.X.ipv4 or lxc.network.X.ipv6
-				if len(fields) == 4 && slices.Contains([]string{"ipv4", "ipv6"}, fields[3]) {
-					continue
-				}
-
-				// lxc.network.X.ipv4.gateway or lxc.network.X.ipv6.gateway
-				if len(fields) == 5 && slices.Contains([]string{"ipv4", "ipv6"}, fields[3]) && fields[4] == "gateway" {
-					continue
-				}
-			} else {
-				// lxc.net.X.ipv4.address or lxc.net.X.ipv6.address
-				if len(fields) == 5 && slices.Contains([]string{"ipv4", "ipv6"}, fields[3]) && fields[4] == "address" {
-					continue
-				}
-
-				// lxc.net.X.ipv4.gateway or lxc.net.X.ipv6.gateway
-				if len(fields) == 5 && slices.Contains([]string{"ipv4", "ipv6"}, fields[3]) && fields[4] == "gateway" {
-					continue
-				}
-			}
-
-			return fmt.Errorf("Only interface-specific ipv4/ipv6 %s keys are allowed", networkKeyPrefix)
-		}
 	}
 
 	return nil
@@ -636,6 +602,8 @@ func SuitableArchitectures(ctx context.Context, s *state.State, tx *db.ClusterTx
 					Proxy:         s.Proxy,
 					CachePath:     s.OS.CacheDir,
 					CacheExpiry:   time.Hour,
+					SkipGetEvents: true,
+					SkipGetServer: true,
 				})
 				if err != nil {
 					return nil, err
