@@ -205,8 +205,8 @@ func (d *lvm) DeleteVolume(vol Volume, op *operations.Operation) error {
 		return errors.New("Cannot remove a volume that has snapshots")
 	}
 
-	volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
-	lvExists, err := d.logicalVolumeExists(volDevPath)
+	volPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
+	lvExists, err := d.logicalVolumeExists(volPath)
 	if err != nil {
 		return err
 	}
@@ -219,7 +219,7 @@ func (d *lvm) DeleteVolume(vol Volume, op *operations.Operation) error {
 			}
 		}
 
-		err = d.removeLogicalVolume(d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name))
+		err = d.removeLogicalVolume(d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name))
 		if err != nil {
 			return fmt.Errorf("Error removing LVM logical volume: %w", err)
 		}
@@ -255,8 +255,8 @@ func (d *lvm) DeleteVolume(vol Volume, op *operations.Operation) error {
 
 // HasVolume indicates whether a specific volume exists on the storage pool.
 func (d *lvm) HasVolume(vol Volume) (bool, error) {
-	volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
-	return d.logicalVolumeExists(volDevPath)
+	volPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
+	return d.logicalVolumeExists(volPath)
 }
 
 // FillVolumeConfig populate volume with default config.
@@ -393,8 +393,8 @@ func (d *lvm) GetVolumeUsage(vol Volume) (int64, error) {
 	} else if vol.contentType == ContentTypeBlock && d.usesThinpool() {
 		// For non-snapshot thin pool block volumes we can calculate an approximate usage using the space
 		// allocated to the volume from the thin pool.
-		volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
-		_, usedSize, err := d.thinPoolVolumeUsage(volDevPath)
+		volPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
+		_, usedSize, err := d.thinPoolVolumeUsage(volPath)
 		if err != nil {
 			return -1, err
 		}
@@ -419,8 +419,8 @@ func (d *lvm) SetVolumeQuota(vol Volume, size string, allowUnsafeResize bool, op
 	}
 
 	// Read actual size of current volume.
-	volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
-	oldSizeBytes, err := d.logicalVolumeSize(volDevPath)
+	volPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
+	oldSizeBytes, err := d.logicalVolumeSize(volPath)
 	if err != nil {
 		return err
 	}
@@ -442,7 +442,7 @@ func (d *lvm) SetVolumeQuota(vol Volume, size string, allowUnsafeResize bool, op
 		return nil
 	}
 
-	l := d.logger.AddContext(logger.Ctx{"dev": volDevPath, "size": fmt.Sprintf("%db", sizeBytes)})
+	l := d.logger.AddContext(logger.Ctx{"dev": volPath, "size": fmt.Sprintf("%db", sizeBytes)})
 
 	inUse := vol.MountInUse()
 
@@ -477,6 +477,11 @@ func (d *lvm) SetVolumeQuota(vol Volume, size string, allowUnsafeResize bool, op
 			// so that we can have more control over when we trigger unsafe filesystem resize mode,
 			// otherwise by passing -f to lvresize (required for other reasons) this would then pass
 			// -f onto resize2fs as well.
+			volDevPath, err := d.lvmDevPath(volPath)
+			if err != nil {
+				return err
+			}
+
 			err = shrinkFileSystem(fsType, volDevPath, vol, sizeBytes, allowUnsafeResize)
 			if err != nil {
 				_, _ = d.deactivateVolume(vol)
@@ -492,7 +497,7 @@ func (d *lvm) SetVolumeQuota(vol Volume, size string, allowUnsafeResize bool, op
 			l.Debug("Logical volume filesystem shrunk")
 
 			// Shrink the block device.
-			err = d.resizeLogicalVolume(volDevPath, sizeBytes)
+			err = d.resizeLogicalVolume(volPath, sizeBytes)
 			if err != nil {
 				return err
 			}
@@ -506,7 +511,7 @@ func (d *lvm) SetVolumeQuota(vol Volume, size string, allowUnsafeResize bool, op
 			defer release()
 
 			// Grow block device first.
-			err = d.resizeLogicalVolume(volDevPath, sizeBytes)
+			err = d.resizeLogicalVolume(volPath, sizeBytes)
 			if err != nil {
 				return err
 			}
@@ -524,6 +529,11 @@ func (d *lvm) SetVolumeQuota(vol Volume, size string, allowUnsafeResize bool, op
 			}
 
 			// Grow the filesystem to fill block device.
+			volDevPath, err := d.lvmDevPath(volPath)
+			if err != nil {
+				return err
+			}
+
 			err = growFileSystem(fsType, volDevPath, vol)
 			if err != nil {
 				return err
@@ -549,7 +559,7 @@ func (d *lvm) SetVolumeQuota(vol Volume, size string, allowUnsafeResize bool, op
 		defer release()
 
 		// Resize the block device.
-		err = d.resizeLogicalVolume(volDevPath, sizeBytes)
+		err = d.resizeLogicalVolume(volPath, sizeBytes)
 		if err != nil {
 			return err
 		}
@@ -569,6 +579,11 @@ func (d *lvm) SetVolumeQuota(vol Volume, size string, allowUnsafeResize bool, op
 			}
 
 			// Discard the new blocks.
+			volDevPath, err := d.lvmDevPath(volPath)
+			if err != nil {
+				return err
+			}
+
 			err = linux.ClearBlock(volDevPath, oldSizeBytes)
 			if err != nil {
 				return err
@@ -591,6 +606,11 @@ func (d *lvm) SetVolumeQuota(vol Volume, size string, allowUnsafeResize bool, op
 			}
 
 			// Move the GPT alt header.
+			volDevPath, err := d.lvmDevPath(volPath)
+			if err != nil {
+				return err
+			}
+
 			err = d.moveGPTAltHeader(volDevPath)
 			if err != nil {
 				return err
@@ -604,8 +624,7 @@ func (d *lvm) SetVolumeQuota(vol Volume, size string, allowUnsafeResize bool, op
 // GetVolumeDiskPath returns the location of a disk volume.
 func (d *lvm) GetVolumeDiskPath(vol Volume) (string, error) {
 	if vol.IsVMBlock() || (vol.volType == VolumeTypeCustom && IsContentBlock(vol.contentType)) {
-		volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
-		return volDevPath, nil
+		return d.lvmDevPath(d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name))
 	}
 
 	return "", ErrNotSupported
@@ -741,7 +760,10 @@ func (d *lvm) MountVolume(vol Volume, op *operations.Operation) error {
 		mountPath := vol.MountPath()
 		if !linux.IsMountPoint(mountPath) {
 			fsType := vol.ConfigBlockFilesystem()
-			volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
+			volDevPath, err := d.lvmDevPath(d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name))
+			if err != nil {
+				return err
+			}
 
 			if vol.mountFilesystemProbe {
 				fsType, err = fsProbe(volDevPath)
@@ -828,8 +850,12 @@ func (d *lvm) UnmountVolume(vol Volume, keepBlockDev bool, op *operations.Operat
 			}
 		}
 
-		volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
-		if !keepBlockDev && util.PathExists(volDevPath) {
+		volDevPath, err := d.lvmDevPath(d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name))
+		if err != nil && !errors.Is(err, os.ErrNotExist) {
+			return false, err
+		}
+
+		if !keepBlockDev && volDevPath != "" {
 			if refCount > 0 {
 				d.logger.Debug("Skipping unmount as in use", logger.Ctx{"volName": vol.name, "refCount": refCount})
 				return false, ErrInUse
@@ -849,7 +875,7 @@ func (d *lvm) UnmountVolume(vol Volume, keepBlockDev bool, op *operations.Operat
 
 // RenameVolume renames a volume and its snapshots.
 func (d *lvm) RenameVolume(vol Volume, newVolName string, op *operations.Operation) error {
-	volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
+	volPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
 
 	return vol.UnmountTask(func(op *operations.Operation) error {
 		snapNames, err := d.VolumeSnapshots(vol, op)
@@ -863,15 +889,15 @@ func (d *lvm) RenameVolume(vol Volume, newVolName string, op *operations.Operati
 		// Rename snapshots (change volume prefix to use new parent volume name).
 		for _, snapName := range snapNames {
 			snapVolName := GetSnapshotVolumeName(vol.name, snapName)
-			snapVolDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, snapVolName)
+			snapVolPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, snapVolName)
 			newSnapVolName := GetSnapshotVolumeName(newVolName, snapName)
-			newSnapVolDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, newSnapVolName)
-			err = d.renameLogicalVolume(snapVolDevPath, newSnapVolDevPath)
+			newSnapVolPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, newSnapVolName)
+			err = d.renameLogicalVolume(snapVolPath, newSnapVolPath)
 			if err != nil {
 				return err
 			}
 
-			reverter.Add(func() { _ = d.renameLogicalVolume(newSnapVolDevPath, snapVolDevPath) })
+			reverter.Add(func() { _ = d.renameLogicalVolume(newSnapVolPath, snapVolPath) })
 		}
 
 		// Rename snapshots dir if present.
@@ -889,13 +915,13 @@ func (d *lvm) RenameVolume(vol Volume, newVolName string, op *operations.Operati
 		}
 
 		// Rename actual volume.
-		newVolDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, newVolName)
-		err = d.renameLogicalVolume(volDevPath, newVolDevPath)
+		newVolPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, newVolName)
+		err = d.renameLogicalVolume(volPath, newVolPath)
 		if err != nil {
 			return err
 		}
 
-		reverter.Add(func() { _ = d.renameLogicalVolume(newVolDevPath, volDevPath) })
+		reverter.Add(func() { _ = d.renameLogicalVolume(newVolPath, volPath) })
 
 		// Rename volume dir.
 		if vol.contentType == ContentTypeFS {
@@ -932,9 +958,14 @@ func (d *lvm) MigrateVolume(vol Volume, conn io.ReadWriteCloser, volSrcArgs *mig
 			defer lvmActivation.Unlock()
 
 			// Block volume.
-			volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.Name())
-			if util.PathExists(volDevPath) {
-				_, err := subprocess.RunCommand("lvchange", "--activate", "sy", "--ignoreactivationskip", volDevPath)
+			volPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.Name())
+			volDevPath, err := d.lvmDevPath(volPath)
+			if err != nil && !errors.Is(err, os.ErrNotExist) {
+				return err
+			}
+
+			if volDevPath != "" {
+				_, err := subprocess.RunCommand("lvchange", "--activate", "sy", "--ignoreactivationskip", volPath)
 				if err != nil {
 					return err
 				}
@@ -943,10 +974,15 @@ func (d *lvm) MigrateVolume(vol Volume, conn io.ReadWriteCloser, volSrcArgs *mig
 			// Filesystem volume.
 			if vol.IsVMBlock() {
 				fsVol := vol.NewVMBlockFilesystemVolume()
-				volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], fsVol.volType, fsVol.contentType, fsVol.Name())
 
-				if util.PathExists(volDevPath) {
-					_, err := subprocess.RunCommand("lvchange", "--activate", "sy", "--ignoreactivationskip", volDevPath)
+				volPath := d.lvmPath(d.config["lvm.vg_name"], fsVol.volType, fsVol.contentType, fsVol.Name())
+				volDevPath, err := d.lvmDevPath(volPath)
+				if err != nil && !errors.Is(err, os.ErrNotExist) {
+					return err
+				}
+
+				if volDevPath != "" {
+					_, err := subprocess.RunCommand("lvchange", "--activate", "sy", "--ignoreactivationskip", volPath)
 					if err != nil {
 						return err
 					}
@@ -994,10 +1030,10 @@ func (d *lvm) CreateVolumeSnapshot(snapVol Volume, op *operations.Operation) err
 		return fmt.Errorf("Error creating LVM logical volume snapshot: %w", err)
 	}
 
-	volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, snapVol.name)
+	volPath := d.lvmPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, snapVol.name)
 
 	reverter.Add(func() {
-		_ = d.removeLogicalVolume(volDevPath)
+		_ = d.removeLogicalVolume(volPath)
 	})
 
 	// For VMs, also snapshot the filesystem.
@@ -1018,8 +1054,8 @@ func (d *lvm) CreateVolumeSnapshot(snapVol Volume, op *operations.Operation) err
 // must be bare names and should not be in the format "volume/snapshot".
 func (d *lvm) DeleteVolumeSnapshot(snapVol Volume, op *operations.Operation) error {
 	// Remove the snapshot from the storage device.
-	volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, snapVol.name)
-	lvExists, err := d.logicalVolumeExists(volDevPath)
+	volPath := d.lvmPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, snapVol.name)
+	lvExists, err := d.logicalVolumeExists(volPath)
 	if err != nil {
 		return err
 	}
@@ -1030,7 +1066,7 @@ func (d *lvm) DeleteVolumeSnapshot(snapVol Volume, op *operations.Operation) err
 			return fmt.Errorf("Error unmounting LVM logical volume: %w", err)
 		}
 
-		err = d.removeLogicalVolume(d.lvmDevPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, snapVol.name))
+		err = d.removeLogicalVolume(d.lvmPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, snapVol.name))
 		if err != nil {
 			return fmt.Errorf("Error removing LVM logical volume: %w", err)
 		}
@@ -1109,21 +1145,27 @@ func (d *lvm) MountVolumeSnapshot(snapVol Volume, op *operations.Operation) erro
 			}
 
 			reverter.Add(func() {
-				_ = d.removeLogicalVolume(d.lvmDevPath(d.config["lvm.vg_name"], tmpVol.volType, tmpVol.contentType, tmpVol.name))
+				_ = d.removeLogicalVolume(d.lvmPath(d.config["lvm.vg_name"], tmpVol.volType, tmpVol.contentType, tmpVol.name))
 			})
 
 			// We are going to mount the temporary volume instead.
 			mountVol = tmpVol
 		}
 
-		volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], mountVol.volType, mountVol.contentType, mountVol.name)
-
 		// Activate volume if needed.
 		_, err = d.activateVolume(mountVol)
 		if err != nil {
 			return err
 		}
 
+		// Get volume path.
+		volPath := d.lvmPath(d.config["lvm.vg_name"], mountVol.volType, mountVol.contentType, mountVol.name)
+
+		volDevPath, err := d.lvmDevPath(volPath)
+		if err != nil {
+			return err
+		}
+
 		if regenerateFSUUID {
 			tmpVolFsType := mountVol.ConfigBlockFilesystem()
 
@@ -1135,7 +1177,7 @@ func (d *lvm) MountVolumeSnapshot(snapVol Volume, op *operations.Operation) erro
 					mountOptions += ",nouuid"
 				}
 			} else {
-				d.logger.Debug("Regenerating filesystem UUID", logger.Ctx{"dev": volDevPath, "fs": tmpVolFsType})
+				d.logger.Debug("Regenerating filesystem UUID", logger.Ctx{"dev": volPath, "fs": tmpVolFsType})
 				err = regenerateFilesystemUUID(mountVol.ConfigBlockFilesystem(), volDevPath)
 				if err != nil {
 					return err
@@ -1149,7 +1191,7 @@ func (d *lvm) MountVolumeSnapshot(snapVol Volume, op *operations.Operation) erro
 			return fmt.Errorf("Failed to mount LVM snapshot volume: %w", err)
 		}
 
-		d.logger.Debug("Mounted logical volume snapshot", logger.Ctx{"dev": volDevPath, "path": mountPath, "options": mountOptions})
+		d.logger.Debug("Mounted logical volume snapshot", logger.Ctx{"dev": volPath, "path": mountPath, "options": mountOptions})
 	} else if snapVol.contentType == ContentTypeBlock {
 		// Activate volume if needed.
 		_, err = d.activateVolume(snapVol)
@@ -1203,16 +1245,16 @@ func (d *lvm) UnmountVolumeSnapshot(snapVol Volume, op *operations.Operation) (b
 
 		// Check if a temporary snapshot exists, and if so remove it.
 		tmpVolName := fmt.Sprintf("%s%s", snapVol.name, tmpVolSuffix)
-		tmpVolDevPath := d.lvmDevPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, tmpVolName)
-		exists, err := d.logicalVolumeExists(tmpVolDevPath)
+		tmpVolPath := d.lvmPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, tmpVolName)
+		exists, err := d.logicalVolumeExists(tmpVolPath)
 		if err != nil {
-			return true, fmt.Errorf("Failed to check existence of temporary LVM snapshot volume %q: %w", tmpVolDevPath, err)
+			return true, fmt.Errorf("Failed to check existence of temporary LVM snapshot volume %q: %w", tmpVolPath, err)
 		}
 
 		if exists {
-			err = d.removeLogicalVolume(tmpVolDevPath)
+			err = d.removeLogicalVolume(tmpVolPath)
 			if err != nil {
-				return true, fmt.Errorf("Failed to remove temporary LVM snapshot volume %q: %w", tmpVolDevPath, err)
+				return true, fmt.Errorf("Failed to remove temporary LVM snapshot volume %q: %w", tmpVolPath, err)
 			}
 		}
 
@@ -1234,8 +1276,13 @@ func (d *lvm) UnmountVolumeSnapshot(snapVol Volume, op *operations.Operation) (b
 			}
 		}
 
-		volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, snapVol.name)
-		if util.PathExists(volDevPath) {
+		volPath := d.lvmPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, snapVol.name)
+		volDevPath, err := d.lvmDevPath(volPath)
+		if err != nil && !errors.Is(err, os.ErrNotExist) {
+			return false, err
+		}
+
+		if volDevPath != "" {
 			if refCount > 0 {
 				d.logger.Debug("Skipping unmount as in use", logger.Ctx{"volName": snapVol.name, "refCount": refCount})
 				return false, ErrInUse
@@ -1320,19 +1367,19 @@ func (d *lvm) RestoreVolume(vol Volume, snapshotName string, op *operations.Oper
 			return fmt.Errorf("Error unmounting LVM logical volume: %w", err)
 		}
 
-		originalVolDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
+		originalVolPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
 		tmpVolName := fmt.Sprintf("%s%s", vol.name, tmpVolSuffix)
-		tmpVolDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, tmpVolName)
+		tmpVolPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, tmpVolName)
 
 		// Rename original logical volume to temporary new name so we can revert if needed.
-		err = d.renameLogicalVolume(originalVolDevPath, tmpVolDevPath)
+		err = d.renameLogicalVolume(originalVolPath, tmpVolPath)
 		if err != nil {
 			return fmt.Errorf("Error temporarily renaming original LVM logical volume: %w", err)
 		}
 
 		reverter.Add(func() {
 			// Rename the original volume back to the original name.
-			_ = d.renameLogicalVolume(tmpVolDevPath, originalVolDevPath)
+			_ = d.renameLogicalVolume(tmpVolPath, originalVolPath)
 		})
 
 		// Create writable snapshot from source snapshot named as target volume.
@@ -1341,10 +1388,10 @@ func (d *lvm) RestoreVolume(vol Volume, snapshotName string, op *operations.Oper
 			return fmt.Errorf("Error restoring LVM logical volume snapshot: %w", err)
 		}
 
-		volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
+		volPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
 
 		reverter.Add(func() {
-			_ = d.removeLogicalVolume(volDevPath)
+			_ = d.removeLogicalVolume(volPath)
 		})
 
 		// If the volume's filesystem needs to have its UUID regenerated to allow mount then do so now.
@@ -1354,7 +1401,13 @@ func (d *lvm) RestoreVolume(vol Volume, snapshotName string, op *operations.Oper
 				return err
 			}
 
-			d.logger.Debug("Regenerating filesystem UUID", logger.Ctx{"dev": volDevPath, "fs": vol.ConfigBlockFilesystem()})
+			d.logger.Debug("Regenerating filesystem UUID", logger.Ctx{"dev": volPath, "fs": vol.ConfigBlockFilesystem()})
+
+			volDevPath, err := d.lvmDevPath(volPath)
+			if err != nil {
+				return err
+			}
+
 			err = regenerateFilesystemUUID(vol.ConfigBlockFilesystem(), volDevPath)
 			if err != nil {
 				return err
@@ -1362,7 +1415,7 @@ func (d *lvm) RestoreVolume(vol Volume, snapshotName string, op *operations.Oper
 		}
 
 		// Finally remove the original logical volume. Should always be the last step to allow revert.
-		err = d.removeLogicalVolume(d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, tmpVolName))
+		err = d.removeLogicalVolume(d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, tmpVolName))
 		if err != nil {
 			return fmt.Errorf("Error removing original LVM logical volume: %w", err)
 		}
@@ -1394,7 +1447,7 @@ func (d *lvm) RestoreVolume(vol Volume, snapshotName string, op *operations.Oper
 	// limits the new size to the maximum CoW size that the snapshot can be (which happens to be the same size
 	// as newer snapshots are taken at using the "100%ORIGIN" size). Confusing isn't it.
 	if snapVol.IsVMBlock() || snapVol.contentType == ContentTypeFS {
-		snapLVPath := d.lvmDevPath(d.config["lvm.vg_name"], snapVol.volType, ContentTypeFS, snapVol.name)
+		snapLVPath := d.lvmPath(d.config["lvm.vg_name"], snapVol.volType, ContentTypeFS, snapVol.name)
 		_, err = subprocess.TryRunCommand("lvresize", "-l", "+100%ORIGIN", "-f", snapLVPath)
 		if err != nil {
 			return err
@@ -1402,7 +1455,7 @@ func (d *lvm) RestoreVolume(vol Volume, snapshotName string, op *operations.Oper
 	}
 
 	if snapVol.IsVMBlock() || (snapVol.contentType == ContentTypeBlock && snapVol.volType == VolumeTypeCustom) {
-		snapLVPath := d.lvmDevPath(d.config["lvm.vg_name"], snapVol.volType, ContentTypeBlock, snapVol.name)
+		snapLVPath := d.lvmPath(d.config["lvm.vg_name"], snapVol.volType, ContentTypeBlock, snapVol.name)
 		_, err = subprocess.TryRunCommand("lvresize", "-l", "+100%ORIGIN", "-f", snapLVPath)
 		if err != nil {
 			return err
@@ -1465,12 +1518,12 @@ func (d *lvm) RestoreVolume(vol Volume, snapshotName string, op *operations.Oper
 
 // RenameVolumeSnapshot renames a volume snapshot.
 func (d *lvm) RenameVolumeSnapshot(snapVol Volume, newSnapshotName string, op *operations.Operation) error {
-	volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, snapVol.name)
+	volPath := d.lvmPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, snapVol.name)
 
 	parentName, _, _ := api.GetParentAndSnapshotName(snapVol.name)
 	newSnapVolName := GetSnapshotVolumeName(parentName, newSnapshotName)
-	newVolDevPath := d.lvmDevPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, newSnapVolName)
-	err := d.renameLogicalVolume(volDevPath, newVolDevPath)
+	newVolPath := d.lvmPath(d.config["lvm.vg_name"], snapVol.volType, snapVol.contentType, newSnapVolName)
+	err := d.renameLogicalVolume(volPath, newVolPath)
 	if err != nil {
 		return fmt.Errorf("Error renaming LVM logical volume: %w", err)
 	}
